@@ -4,6 +4,7 @@ from plantuml2freemind.custom_types import ParserType
 from plantuml2freemind.parsers import plantuml, yaml
 
 PARSERS: Dict[str, ParserType] = {
-    '.puml': plantuml.entry,
-    '.yaml': yaml.entry,
-}
\ No newline at end of file
+    ".puml": plantuml.entry,
+    ".yaml": yaml.entry,
+    ".json": yaml.entry,
+}
